@@ -1,16 +1,16 @@
 package Thread::Conveyor::Array;
 
-# Make sure we are a belt
 # Make sure we have version info for this module
+# Make sure we are a belt
 # Make sure we do everything by the book from now on
 
+$VERSION = '0.13';
 @ISA = qw(Thread::Conveyor);
-$VERSION = '0.12';
 use strict;
 
 # Make sure we only load stuff when we actually need it
 
-use AutoLoader ();
+use load;
 
 # Satisfy -require-
 
@@ -18,6 +18,12 @@ use AutoLoader ();
 
 #---------------------------------------------------------------------------
 
+# The following subroutines are loaded only on demand
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # Class methods
 
 #---------------------------------------------------------------------------
@@ -47,12 +53,6 @@ sub semaphore { shift } # semaphore
 
 #---------------------------------------------------------------------------
 
-# AutoLoader takes over from here
-
-__END__
-
-#---------------------------------------------------------------------------
-
 # Object methods
 
 #---------------------------------------------------------------------------
@@ -267,6 +267,8 @@ sub _clean {
 
 #---------------------------------------------------------------------------
 
+__END__
+
 =head1 NAME
 
 Thread::Conveyor::Array - array implementation of Thread::Conveyor
