@@ -1,16 +1,16 @@
 package Thread::Conveyor::Throttled;
 
-# Make sure we're a conveyor belt
 # Make sure we have version info for this module
+# Make sure we're a conveyor belt
 # Make sure we do everything by the book from now on
 
+$VERSION = '0.13';
 @ISA = qw(Thread::Conveyor);
-$VERSION = '0.12';
 use strict;
 
 # Make sure we only load stuff when we actually need it
 
-use AutoLoader ();
+use load;
 
 # Satisfy -require-
 
@@ -18,6 +18,12 @@ use AutoLoader ();
 
 #---------------------------------------------------------------------------
 
+# The following subroutines are loaded only on demand
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # Class methods
 
 #---------------------------------------------------------------------------
@@ -45,12 +51,6 @@ sub new {
 
 #---------------------------------------------------------------------------
 
-# AutoLoader takes over from here
-
-__END__
-
-#---------------------------------------------------------------------------
-
 # object methods
 
 #---------------------------------------------------------------------------
@@ -257,6 +257,8 @@ sub _clean { shift->{'belt'}->_clean } #_clean
 
 #---------------------------------------------------------------------------
 
+__END__
+
 =head1 NAME
 
 Thread::Conveyor::Throttled - helper class of Thread::Conveyor
